@@ -105,10 +105,8 @@ class ConfigureCmd(Command):
             capture_config['Arguments']['ip-address'] = my_meter["ip_address"]
             capture_config['Arguments']['daq-type'] = my_meter["daq_type"]
             if(my_meter['daq_type'] == "nerdjack"):
-                if(my_meter["sensors"]["filter"]["keep"] == True):
+                if(my_meter["sensors"]["filter"]["enabled"] == True):
                     capture_config['Arguments']['filter-index'] = "%i"%my_meter["sensors"]["filter"]["filter_index"]
-                else:
-                    capture_config['Arguments']['filter-index'] = None
             
         else:
             capture_config['Arguments']['tty'] = my_meter["tty"]
@@ -180,7 +178,7 @@ class ConfigureCmd(Command):
             if(my_meter['daq_type'] == "labjack"):
                 num_channels = 6
             if(my_meter['daq_type'] == "nerdjack"):
-                if(my_meter["sensors"]["filter"]["keep"] == True):
+                if(my_meter["sensors"]["filter"]["enabled"] == True):
                     num_channels = 7
                 else:
                     num_channels = 6
