@@ -172,12 +172,19 @@ class ScopeCmd(Command):
             dead_loops = 0
             sensor_data = sensor_data - np.mean(sensor_data, axis=0)
             #           fig.canvas.restore_region(bkgd)
+            bounds = ax.get_ylim()
+            plot_range = bounds[1]-bounds[0]
             for i in range(len(channels)):
                 points = data[i]
                 idx = channels[i] + 1  # ts is column 0
                 cur_data = points.get_data()
+                sensor_vals = sensor_data[:self.plot_width, idx]
+                data_range = np.max(sensor_vals)-np.min(sensor_vals)
+                scale_factor = plot_range/data_range
+                if scale_factor < 1: # data range is too big, shrink it
+                    sensor_vals *= scale_factor*0.9 # take up 90% of the plot area
                 points.set_data(cur_data[0],
-                                sensor_data[:self.plot_width, idx])
+                                sensor_vals)
             #                ax.draw_artist(points)
             #            fig.canvas.blit(ax.bbox)
             fig.canvas.draw()
