@@ -1,18 +1,20 @@
-from joule import LocalPipe
+import pdb
 import unittest
 import asyncio
 import argparse
 import numpy as np
-from nilm.filters import prep
 from numpy.testing import assert_array_almost_equal
 
+from joule import LocalPipe
+from nilm.filters import prep
+
 
 class TestPrep(unittest.TestCase):
 
     def setUp(self):
         self.loop = asyncio.new_event_loop()
         asyncio.set_event_loop(self.loop)
-        
+
     def tearDown(self):
         self.loop.close()
 
@@ -26,11 +28,11 @@ class TestPrep(unittest.TestCase):
 
         phase_rotations = np.random.rand(PHASES)
         test_iv_data = self._create_iv_data(phase_content,
-                                            phase_rotations)
+                                            phase_rotations, f=50, fs=2000)
         test_zc_data = self._create_zc_data()
 
         npipe_iv = LocalPipe("float32_%d" % (
-            PHASES + 1), name="iv")
+                PHASES + 1), name="iv")
         npipe_zc = LocalPipe("float32_3", name="zc")
         outputs = {}
         for ph in range(PHASES):
@@ -39,6 +41,8 @@ class TestPrep(unittest.TestCase):
 
         npipe_iv.write_nowait(test_iv_data)
         npipe_zc.write_nowait(test_zc_data)
+        npipe_iv.close_nowait()
+        npipe_zc.close_nowait()
 
         args = argparse.Namespace(**{
             # [2,3,4] for 3 phase
@@ -47,28 +51,30 @@ class TestPrep(unittest.TestCase):
             "nshift": 1,
             "nharm": NHARM,
             "scale_factor": 1.0,
+            "samp_freq": 2000,
+            "line_freq": 50,
             "merge": False,
-            "polar": False
+            "polar": False,
+            "goertzel": False
         })
-        
+
         my_filter = prep.Prep()
         loop = asyncio.get_event_loop()
         loop.run_until_complete(
             my_filter.run(args,
                           {"iv": npipe_iv,
                            "zero_crossings": npipe_zc},
-                          outputs,
-                          nrows=len(test_iv_data) - 50))
+                          outputs))
 
         expected_content = np.r_[phase_content]
         expected_content.shape = (1, len(phase_content) * NHARM * 2)
         # make sure prep produced a sample for all of the zero crossings
         # acceptable if we missed one because the end of the data
-        width = NHARM*2
+        width = NHARM * 2
         for ph in range(PHASES):
             name = "prep-%c" % 'abc'[ph]
-            start_i = ph*width
-            end_i = start_i+width
+            start_i = ph * width
+            end_i = start_i + width
             result = outputs[name].read_nowait()
             self.assertGreaterEqual(len(result), len(test_zc_data) - 1)
             ph_cols = list(range(start_i, end_i))
@@ -76,7 +82,7 @@ class TestPrep(unittest.TestCase):
             for row in result:
                 assert_array_almost_equal(np.squeeze(row['data']),
                                           expected_ph_data)
-        
+
     def test_computes_meged_prep(self):
         PHASES = 3
         NHARM = 4
@@ -87,7 +93,8 @@ class TestPrep(unittest.TestCase):
 
         phase_rotations = np.random.rand(PHASES)
         test_iv_data = self._create_iv_data(phase_content,
-                                            phase_rotations)
+                                            phase_rotations,
+                                            f=50, fs=2000)
         test_zc_data = self._create_zc_data()
 
         npipe_iv = LocalPipe("float32_%d" % (PHASES + 1), name="iv")
@@ -96,6 +103,8 @@ class TestPrep(unittest.TestCase):
 
         npipe_iv.write_nowait(test_iv_data)
         npipe_zc.write_nowait(test_zc_data)
+        npipe_iv.close_nowait()
+        npipe_zc.close_nowait()
 
         args = argparse.Namespace(**{
             # [2,3,4] for 3 phase
@@ -105,17 +114,19 @@ class TestPrep(unittest.TestCase):
             "nharm": NHARM,
             "scale_factor": 1.0,
             "merge": True,
-            "polar": False
+            "polar": False,
+            "samp_freq": 2000,
+            "line_freq": 50,
+            "goertzel": False
         })
         my_filter = prep.Prep()
-        
+
         loop = asyncio.get_event_loop()
         loop.run_until_complete(
             my_filter.run(args,
                           {"iv": npipe_iv,
                            "zero_crossings": npipe_zc},
-                          {"prep": npipe_prep},
-                          nrows=len(test_iv_data) - 50))
+                          {"prep": npipe_prep}))
         result = npipe_prep.read_nowait()
         expected_content = np.r_[phase_content]
         expected_content.shape = (1, len(phase_content) * NHARM * 2)
@@ -126,18 +137,19 @@ class TestPrep(unittest.TestCase):
         for row in result:
             assert_array_almost_equal(np.squeeze(row['data']),
                                       np.squeeze(expected_content))
-            
+
     def test_computes_mag_pf_prep(self):
         PHASES = 3
         NHARM = 4
 
         phase_content = [[1, 1, 1, -1, 0.01, 3, 0.01, -3],
-                         [1, 0, 3,  0, 4, 1, 3,  2],
-                         [8, 9, 5, -5, 4, 8, 9,  0]]
+                         [1, 0, 3, 0, 4, 1, 3, 2],
+                         [8, 9, 5, -5, 4, 8, 9, 0]]
 
         phase_rotations = np.random.rand(PHASES)
         test_iv_data = self._create_iv_data(phase_content,
-                                            phase_rotations)
+                                            phase_rotations,
+                                            f=50, fs=2000)
         test_zc_data = self._create_zc_data()
 
         npipe_iv = LocalPipe("float32_%d" % (PHASES + 1), name="iv")
@@ -146,6 +158,8 @@ class TestPrep(unittest.TestCase):
 
         npipe_iv.write_nowait(test_iv_data)
         npipe_zc.write_nowait(test_zc_data)
+        npipe_iv.close_nowait()
+        npipe_zc.close_nowait()
 
         args = argparse.Namespace(**{
             # [2,3,4] for 3 phase
@@ -155,18 +169,20 @@ class TestPrep(unittest.TestCase):
             "nharm": NHARM,
             "scale_factor": 1.0,
             "merge": True,
-            "polar": True
+            "polar": True,
+            "samp_freq": 2000,
+            "line_freq": 50,
+            "goertzel": False
         })
         my_filter = prep.Prep()
-        
+
         loop = asyncio.get_event_loop()
-        
+
         loop.run_until_complete(
             my_filter.run(args,
                           {"iv": npipe_iv,
                            "zero_crossings": npipe_zc},
-                          {"prep": npipe_prep},
-                          nrows=len(test_iv_data) - 50))
+                          {"prep": npipe_prep}))
         result = npipe_prep.read_nowait()
         expected_content = np.empty(np.shape(phase_content))
         for i in range(PHASES):
@@ -175,7 +191,7 @@ class TestPrep(unittest.TestCase):
                 expected_content[i, 2 * k] = \
                     np.linalg.norm([pq[2 * k], pq[2 * k + 1]])
                 expected_content[i, 2 * k + 1] = \
-                    np.angle(pq[2 * k] + pq[2 * k + 1]*1j) * -2 / np.pi
+                    np.angle(pq[2 * k] + pq[2 * k + 1] * 1j) * -2 / np.pi
 
         # make sure prep produced a sample for all of the zero crossings
         # acceptable if we missed one because the end of the data
